#!/usr/bin/env bash

# Copyright 2016 The Kubernetes Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This script checks the description format of help message of kubectl command
# is valid or not. And this checking is done for all kubectl sub-commands.
# Usage: `hack/verify-cli-conventions.sh`.

set -o errexit
set -o nounset
set -o pipefail

KUBE_ROOT=$(dirname "${BASH_SOURCE[0]}")/..
source "${KUBE_ROOT}/hack/lib/init.sh"

kube::golang::setup_env

GOPROXY=off go install ./cmd/clicheck

if ! output=$(clicheck 2>&1)
then
	echo "$output"
	echo
	echo "FAILURE: CLI is not following one or more required conventions."
	exit 1
else
	echo "$output"
	echo
  echo "SUCCESS: CLI is following all tested conventions."
fi
